Module server

Module server 

HTTP server implementation.

Structs

ServerConfig
Configuration for the HTTP server.

Enums

ServerError
Errors that can occur while starting or running the HTTP server.

Functions

bind
Bind a TCP listener for the given configuration without starting the Axum server.
serve
Bind and start the HTTP server, shutting down gracefully on SIGINT/SIGTERM.