pub fn tower_http_layer() -> Option<SentryHttpLayer>Expand description
Returns a tower HTTP layer that enriches Sentry events when telemetry is initialized.
pub fn tower_http_layer() -> Option<SentryHttpLayer>Returns a tower HTTP layer that enriches Sentry events when telemetry is initialized.