pub fn tower_new_layer() -> Option<NewSentryLayer<Request<Body>>>Expand description
Returns a tower layer that binds a Sentry hub to each request when telemetry is initialized.
pub fn tower_new_layer() -> Option<NewSentryLayer<Request<Body>>>Returns a tower layer that binds a Sentry hub to each request when telemetry is initialized.