Module tracing_init

Module tracing_init 

Tracing subscriber initialization.

Functions

init
Installs a hardcoded tracing subscriber writing to stderr at INFO level with pretty format.
try_init
Installs the tracing subscriber, returning an error if one is already set.