init

Function init 

pub fn init()
Installs a hardcoded tracing subscriber writing to stderr at INFO level with pretty format.

Panics

Panics if a global subscriber has already been installed. In tests, use try_init instead.