Module server
docspec_
http
1.3.0
Module server
Module Items
Structs
Enums
Functions
In crate docspec_
http
docspec_http
Module
server
HTTP server implementation.
Structs

Server
Config
Configuration for the HTTP server.
Enums

Server
Error
Errors that can occur while starting or running the HTTP server.
Functions

bind
Bind a TCP listener for the given configuration without starting the Axum server.
serve
Bind and start the HTTP server, shutting down gracefully on SIGINT/SIGTERM.